% Section 4.2(b) Feature computation
%
% 2011/07/06 OY
% * Bug fix in line 43. 
%   The channel number for Cz is 48 but not 50 as in previous version. 
% 2011/02/25 OY
% 2010/07/31 OY
%
% Copyright (c) 2011, ATR Okito Yamashita, All rights reserved.
 
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');
fprintf(' (b) Compute feature vectors 1 (on Cp3, Cz and Cp4).     \n');
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');



clear all
close all

%---------------------------------------
% Parameters Settings
%---------------------------------------
% Parameter for filename
loadFileName = 'DATA/trialsData.mat';
rejectFileName =  'DATA/ixTrialsRejected.mat';
saveFileName = 'DATA/featurePS1.mat';


% Parameter for spectral estimation
timeAnal_ms = [1.0 4.0]*1000;
timeBase_ms = []*1000;
freqAnal_hz = [9 13;18 25];  % Hz
method = 'pmtm';
%ixChannel = [1:64];
ixChannel = [18 48 55]; % Cp3, Cz, Cp4

%---------------------------- 
% Compute Feature Matrix
%----------------------------

% Load a trial-data file and trial indices to be rejected
load(loadFileName, 'data3', 'time_ms', 'trialLabel', 'runLabel', 'status3', 'Log' )

% Restrict EEG channels
data3 = data3(ixChannel,:,:);

% Using non-rejected trials
if ~isempty(rejectFileName)
    load(rejectFileName, 'ixTrialsRejected');
    ix = setdiff([1:length(trialLabel)], ixTrialsRejected);
    data3 = data3(:,:,ix);
    trialLabel = trialLabel(ix);
end


% Power spectrum
[Nch, Nt, Ntr] = size(data3);

[powAnal, freq_hz, twin] = calc_power_spectrum(data3, 256, time_ms,...
    timeAnal_ms, 0  , 0, method);
[powBase, freqBase_hz] = calc_power_spectrum(data3, 256, time_ms,...
    timeBase_ms, 0, 0, method);

[x] = calcfeat_power(powAnal, freq_hz, freqAnal_hz, powBase, freqBase_hz, 1);

x = reshape(x, [Nch*size(x,2), Ntr]);  
x = x'; % Ntrial * # of feature
y = trialLabel;  % Ntrial * 1

fc_parm.timeAnal_ms = timeAnal_ms;
fc_parm.timeBase_ms = timeBase_ms;
fc_parm.freqAnal_hz = freqAnal_hz;
fc_parm.method      = method
fc_parm.comment = '';
fc_parm.loadFileName = loadFileName;
fc_parm.rejectFileName = rejectFileName;
fc_parm.ixChannel = ixChannel;

Log.fc_parm = fc_parm;


%
save(saveFileName, 'x', 'y', 'Log'); 
fprintf('Save file %s : Done ... \n', saveFileName);

