% Section 4.2(b) figure 4.7
% 
% 2011/07/06 OY
% * Bug fix in line 43. 
%   The channel number for Cz is 48 but not 50 as in previous version.
% 2011/02/25  
%
% Copyright (c) 2011, ATR Okito Yamashita, All rights reserved.

fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');
fprintf(' This program reproduces figure 4.7.          \n');
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');



clear all
close all

load('DATA/trialsData.mat', 'data3', 'time_ms', 'trialLabel', 'runLabel')
load('DATA/ixTrialsRejected.mat', 'ixTrialsRejected');

% Non-rejected Trials
ix = setdiff([1:210], ixTrialsRejected);
data3 = data3(:,:,ix);
trialLabel = trialLabel(ix);

% Analysis and Plot Parameters 
timeAnal_ms = [1.0 4.0]*1000;
timeBase_ms = [-1 0]*1000;
channelPlotted = [18 48 55]; 
channelLabel = {'CP3', 'Cz', 'CP4'};

trialPlotted1 = [38 65 124 135 156];
trialPlotted2 = [52 83 140 150 180];

for ii = 1 : length(trialPlotted1)
    jx1(ii) = find(ix == trialPlotted1(ii));
    jx2(ii) = find(ix == trialPlotted2(ii));
end

%
% Compute power spectrum
%


[Nch, Nt, Ntr] = size(data3);

[powAnal, freq_hz, twin] = calc_power_spectrum(data3, 256, time_ms,...
    timeAnal_ms, 0, 0, 'pmtm');
[powBase, freqBase_hz] = calc_power_spectrum(data3, 256, time_ms,...
    timeBase_ms, 0, 0, 'pmtm');

%
% Plot powerspectrum of trial-averaged data
%

% Average power of label1 and label2
pow1 = squeeze(mean(powAnal(:,:,:,trialLabel==1),4));
pow2 = squeeze(mean(powAnal(:,:,:,trialLabel==2),4));
std1 = squeeze(std(powAnal(:,:,:,trialLabel==1),[],4));
std2 = squeeze(std(powAnal(:,:,:,trialLabel==2),[],4));

ixf = find(freq_hz < 40 & freq_hz > 1);

figure,
for ch = 1 : length(channelPlotted),
    subplot(length(channelPlotted),1,ch),
    plot(freq_hz(ixf), pow1(channelPlotted(ch),ixf), 'linewidth',2);
    hold on
    plot(freq_hz(ixf), pow2(channelPlotted(ch),ixf), 'r','linewidth',2);
    xlabel('Frequency (Hz)')
    ylabel('Power (microvolot^2)');
    title(['Power Spectrum at ' channelLabel{ch}]);
    if ch == 1
    legend('Right Hand','Left Hand')
    end
end


%
% Plot powerspectrum of single trial data
%

pow1 = squeeze(powAnal(:,:,:,jx1));
pow2 = squeeze(powAnal(:,:,:,jx2));

ixf = find(freq_hz < 40 & freq_hz > 1);


figure,
for ch = 1 : length(channelPlotted),
    subplot(2,length(channelPlotted),ch),
    plot(freq_hz(ixf), squeeze(pow1(channelPlotted(ch),ixf,1:5))', 'k', 'linewidth',1);
    hold on;
    plot(freq_hz(ixf), squeeze(pow1(channelPlotted(ch),ixf,5))', 'k', 'linewidth',3);
    
    title([channelLabel{ch}]);
    if ch == 1
    ylabel('Power (microvolot^2)');
    end
    ylim([0 10])

    subplot(2,length(channelPlotted),ch+3),
    plot(freq_hz(ixf), squeeze(pow2(channelPlotted(ch),ixf,1:5))','k', 'linewidth',1);
    hold on;
    plot(freq_hz(ixf), squeeze(pow2(channelPlotted(ch),ixf,5))', 'k', 'linewidth',3);
    
    xlabel('Frequency (Hz)')
    if ch == 1
    ylabel('Power (microvolot^2)');
    end
  
    ylim([0 10])
end
suptitle('Power Spectrum (Right hand : top pannels, Left hand : bottom pannels)')


