% Section 4.2(c) Learn classifier and evaluate performance using 8-fold cross-validation
%
% In order to run this run, you need to install libSVM, SLR toolbox and MATLAB statistical toolbox.  
% 
% You can download libSVM and SLR in the following links,
%
% libSVM ver.2.8.2 or later   : http://www.csie.ntu.edu.tw/~cjlin/libsvm/
% SLR toolbox ver.1.2.1 alpha :  http://www.cns.atr.jp/~oyamashi/SLR_WEB.html 
% 
%
% 2011/07/07 OY
% 2011/02/25 OY
% 2010/07/31 OY
%
% Copyright (c) 2011, ATR Okito Yamashita, All rights reserved.
 

fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');
fprintf(' (c) Classification of features 1 and features 2         \n');
fprintf('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n');


clear all
close all

%
% Parameter Setting
%
saveFileName = 'DATA/resultClassification.mat';
featureFileName1 = ['DATA/featurePS1.mat'];
featureFileName2 = ['DATA/featurePS2.mat'];
CVfile = ['DATA/ixTrialsCV.mat'];
Ncv = 8;
Nrepeat = 10;

% load filename
load(featureFileName1, 'x','y','Log');
x1 = x;
Log1 = Log;

load(featureFileName2, 'x','y','Log');
x2 = x;
Log2 = Log;


%
% Trial indicies for cross validation
%
if ~isempty(CVfile),
    load(CVfile, 'ixtr', 'ixte');
else
    for nr = 1 : Nrepeat
        [ixtr{nr}, ixte{nr}] = separate_nfoldcv(y, Ncv);
    end
end

%
% 10 times of 8-fold cross validation
%

for nr = 1 : Nrepeat

    % restricted channels & SLR
    [cortr(1,:,nr), corte(1,:,nr)] = cls_repeatho(x1,y,ixtr{nr},ixte{nr},'classify');
    [cortr(2,:,nr), corte(2,:,nr)] = cls_repeatho(x1,y,ixtr{nr},ixte{nr},'svm');
    [cortr(3,:,nr), corte(3,:,nr)] = cls_repeatho(x1,y,ixtr{nr},ixte{nr},'slr');
    % all channels & SLR
    [cortr(4,:,nr), corte(4,:,nr)] = cls_repeatho(x2,y,ixtr{nr},ixte{nr},'classify');
    [cortr(5,:,nr), corte(5,:,nr)] = cls_repeatho(x2,y,ixtr{nr},ixte{nr},'svm');
    [cortr(6,:,nr), corte(6,:,nr), sc(:,nr), cvparm] = cls_repeatho(x2,y,ixtr{nr},ixte{nr},'slr');

end

recortr = reshape(cortr, [size(cortr,1) size(cortr,2)*size(cortr,3)]);
recorte = reshape(corte, [size(corte,1) size(corte,2)*size(corte,3)]);

meancortr = mean(recortr,2)
meancorte = mean(recorte,2)
stdcortr = std(recortr, 1, 2)
stdcorte = std(recorte, 1, 2)

comment = '1,2,3: 3channels, 4,5,6:64 channels, (1,4=classify.m, 2.5=SVM, 3,6=SLR)'; 


save(saveFileName, 'cortr', 'corte', 'sc', 'comment', 'ixtr', 'ixte');
