function [cortr,corte,sc,ho_parm] = cls_repeatho(x,y,ixtrain,ixtest,method)
% Repeated Holdout methods 
%
% Input
%   x : Ntrial * Nfeature  
%   y : label vector
% ixtr, ixte : cell arrays of vectors containing indicies of training and
%              test trials. length(ixtr) and length(ixte) must be equal.
%
% 2011/07/07 OY
% * Training and test trial indicies are taken as inputs.
%
% Copyright (c) 2011, ATR Okito Yamashita, All rights reserved.

if nargin < 5
    method = 'slr';
end


[Ntr,Nfeat] = size(x);
y = y(:); % column vector 

%
if ~iscell(ixtrain),
    IXTR{1} = ixtrain;
    IXTE{1} = ixtest;
else
    IXTR = ixtrain;
    IXTE = ixtest;
end

Nrep = length(IXTR); 


% Holdout validation
sc = zeros(Nfeat,1);
cortr = zeros(Nrep,1);
corte = zeros(Nrep,1);

scale_mode = 'each';
mean_mode = 'each';

for  nr = 1 : Nrep,

    ixte = IXTE{nr};
    ixtr = IXTR{nr};

    xtr = x(ixtr,:);
    xte = x(ixte,:);
    ytr = y(ixtr);
    yte = y(ixte);

    if length(unique(y)) == 2,

        switch lower(method)
            case 'slr',

                if Nfeat < 1000
                   [ww, ix_eff, errT_tr, errT_te, cls_parm] = biclsfy_slrvar(xtr, ytr, xte, yte, 'nlearn', 1000, 'invhessian', 1);
                    sc(ix_eff{1}) = sc(ix_eff{1}) + 1;
                else
                    [ww, ix_eff, errT_tr, errT_te, cls_parm] = biclsfy_slrvar(xtr, ytr, xte, yte, 'nlearn', 1000, 'invhessian', 0);
                    sc(ix_eff{1}) = sc(ix_eff{1}) + 1;
                end

                % Obtain correct rate
                pertr = calc_percor(errT_tr);
                perte = calc_percor(errT_te);


            case 'classify',

                fprintf('--------------------------------------------------------\n');
                fprintf('   RUNNING linear Gaussian Classifier \n');
                fprintf('--------------------------------------------------------\n');

                [xtr, scale, base] = normalize_feature(xtr, scale_mode, mean_mode);
                [xte, scale, base] = normalize_feature(xte, scale_mode, mean_mode, scale, base);

                if license('test', 'statistics_toolbox')
                    [yteh, err] = classify(xte, xtr, ytr, 'linear');
                else
                    [w0,w1,w2,err,yteh] = mygauss_classifier(xtr(ytr==1,:)',xtr(ytr==2,:)',1,xte');
                end
                
                % Obtain correct rate
                pertr = (1 - err)*100;
                perte = length(find(yte == yteh))/length(yte)*100;

                cls_parm = struct;
                
            case 'svm',
                fprintf('--------------------------------------------------------\n');
                fprintf('   RUNNING Linear SVM (Binary version) \n')
                fprintf('--------------------------------------------------------\n');

                [xtr, scale, base] = normalize_feature(xtr, scale_mode, mean_mode);
                [xte, scale, base] = normalize_feature(xte, scale_mode, mean_mode, scale, base);
                
                ops = sprintf('-t 0 -c 1 -r 0 -d 3 -b 1');
                ops2 = sprintf('-b 1');

                % Train:
                Model = svmtrain(ytr, xtr, ops);
                [preds, accur, decVals] = svmpredict(ytr, xtr, Model, ops2);
                pertr = accur(1);
                % Test 
                [preds, accur, decVals] = svmpredict(yte, xte, Model, ops2);
                perte = accur(1);
                
                cls_parm = struct;
                
        end

    else
        [ww, ix_eff, errT_tr, errT_te, cls_parm] = muclsfy_slrvarovo(xtr, ytr, xte, yte, 'nlearn', 1000, 'invhessian', 1);

        for cls = 1 : length(unique(y))
            sc(ix_eff{cls}) = sc(ix_eff{cls}) + 1;
        end
    end
    

    % Obtain correct rate
    cortr(nr)= pertr;
    corte(nr)= perte;
    

end

ho_parm.cls_parm = cls_parm;
ho_parm.ixtr = IXTR;
ho_parm.ixte = IXTE;
ho_parm.Nrepeat = Nrep;
